package cc.smtweb.system.bpm.web.login;

import cc.smtweb.framework.core.annotation.SwBody;
import cc.smtweb.framework.core.annotation.SwParam;
import cc.smtweb.framework.core.annotation.SwPerm;
import cc.smtweb.framework.core.annotation.SwService;
import cc.smtweb.framework.core.common.R;
import cc.smtweb.framework.core.common.SwMap;
import cc.smtweb.framework.core.db.DbEngine;
import cc.smtweb.framework.core.exception.BizException;
import cc.smtweb.framework.core.session.SessionManager;
import cc.smtweb.framework.core.session.UserSession;
import cc.smtweb.system.bpm.web.sys.user.user.UserCache;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@SwService
public class AuthService {
    @SwParam
    private DbEngine dbEngine;

    @SwParam
    private SessionManager sessionManager;

    @SwPerm(SwPerm.NONE)
    public R login(@SwBody LoginVO loginPO) {
        SwMap data = new SwMap();
        UserSession userSession = null;
        try {
            userSession = LoginHelper.login(loginPO);
        } catch (BizException e) {
            data.put("isOk", false);
            data.put("msg", e.getMessage());
            return R.success(data);
        } catch (Exception e) {
            data.put("isOk", false);
            data.put("msg", "系统错误");
            return R.success(data);
        }
        userSession.setSiteId(1);

        LoginAckVO loginAckVO = new LoginAckVO();
        loginAckVO.setUserId(userSession.getUserId());
        loginAckVO.setUserName(UserCache.getInstance().getNameById(userSession.getUserId()));
        loginAckVO.setUserAvatar("");
        loginAckVO.setToken(sessionManager.login(userSession));
        data.put("data", loginAckVO);
        data.put("isOk", true);
        data.put("msg", "");
        return R.success(data);
    }

    @SwPerm()
    public R ping(@SwParam("msg") String msg) {
        return R.success(msg);
    }

    @SwPerm("user:edit")
    public R config(@SwParam("username") String username) {
        return R.success("config: " + username);
    }


    /**
     * 退出登录
     *
     * @return code
     */
    public R logout() {
        sessionManager.logout();
        return R.success();
    }

    // defaultRun 命名的函数是默认函数
//  @SwPerm(SwPerm.NONE)
//  public R defaultRun(@SwPathParam String path) {
//    return R.success(path).put("dao", authDao);
//  }

}
